# Traquitanas

[![Publish Python distributions to PyPI](https://github.com/traquitanas/traquitanas/actions/workflows/publish-to-pypi.yml/badge.svg)](https://github.com/traquitanas/traquitanas/actions/workflows/publish-to-pypi.yml)
<br>
[![Publish Python distributions to TestPyPI](https://github.com/traquitanas/traquitanas/actions/workflows/publish-to-test-pypi.yml/badge.svg)](https://github.com/traquitanas/traquitanas/actions/workflows/publish-to-test-pypi.yml)

- [GitHub](https://github.com/traquitanas/traquitanas)

<br>

Traquitanas, badulaques, secos e molhados.<br>
Por aqui tem de tudo. Tudo junto e misturado!

Todas as coisas que uso no dia a dia... em um só pacote.<br>
Quem sabe um dia encaixoto tudo, separando os temas em pacotes distintos...

O pacote também tem a função de aprender a empacotar as coisas.

<br>

---

### Como Instalar?!

```bash
pip3 install traquitanas --upgrade
```


<br>

---

### Documentação

Para melhores explicações, veja o [wiki](https://github.com/traquitanas/traquitanas/wiki)

<br>

---

### Google Colab

Para testes rápidos sobre o funcionamento do pacote, elaborei um [Google Colab](https://colab.research.google.com/drive/1WfiEeO4jeeiLPiCknGWfvHI-O3b5NbjE?usp=sharing).

<br>

---

### _TODO_

1. Criar _Wiki_
